Información adicional

SERVICIOS |
REGISTRO |
COSTOS |
CONTACTO |

Información del dominio : Ponemos a su disposición datos relacionados exclusivamente para fines de trámite de inscripción de nombres de dominios y funcionamiento DNS. La información presentada no puede ser empleada con fines de envío de mensajes electrónicos no solicitados ("spamming"). La base de datos generada a partir del sistema de inscripción de dominios, es de propiedad de NIC Bolivia.
Organización |  | Microsoft Corporation
Ciudad |  | Redmond, WA
Dirección |  | 1 Microsoft Way
Fecha de Registro |  | 2007-09-14
Responsable Administrativo |  | Microsoft Admin
Responsable Técnico |  | Microsoft Tech
Responsable Financiero |  | Marisol Marquez Burgos
DNS primario |  | ns1.msft.net
IP Primario |  | 207.68.160.190
El Nic Bolivia, tiene la siguiente dirección: Calle Ayacucho Esq. Mercado, Edif. de la Vicepresidencia de la República Piso 3 AGENCIA PARA EL DESARROLLO DE LA SOCIEDAD DE LA INFORMACION EN BOLIVIA Teléfonos: 5912 2200730 - 2200740 Fax: 5912 2200720 Correo Electrónico: soporte@nic.bo INICIO

....

Conexión Internet
Sitios Web
Redes y Sistemas

Procedimiento
Formulario
Decreto
Ayuda

Registro
WebHosting
Pago

ADSIB
Soporte NIC
Teléfonos